# Livecoding Madness: Let's Build a Deep Learning Library

[video](https://www.youtube.com/watch?v=o64FV-ez6Gw) of the livecoding.

[slides](https://docs.google.com/presentation/d/1y9aC4hbNbcpjw9r6BMSayBmEdmdUwR5us_26X3S2j2M/edit?usp=sharing)

--------

[Joel Grus](http://joelgrus.com)

[@joelgrus](https://twitter.com/joelgrus)

research engineer, [Allen Institute for AI](http://allenai.org)

author, [Data Science from Scratch](http://shop.oreilly.com/product/0636920033400.do)

co-host, ["Adversarial Learning" podcast](http://adversariallearning.com)

# Livecoding Madness: Let's Build a Deep Learning Library

In this talk we'll build a deep learning library
from scratch (well, from NumPy) in 45 minutes.

How is that possible? By typing _really_ fast.

Along the way we'll talk about library design,
type hinting, Python 3.6, and of course deep learning.


# Here's the plan:

1. Tensors
2. Loss Functions
3. Layers
4. Neural Nets
5. Optimizers
6. Data
7. Training
8. XOR Example
9. FizzBuzz Example
